OC.L10N.register(
    "core",
    {
    "Please select a file." : "請選擇一個檔案",
    "File is too big" : "檔案太大",
    "Invalid file provided" : "提供的檔案無效",
    "No image or file provided" : "未提供圖片或檔案",
    "Unknown filetype" : "未知的檔案類型",
    "Invalid image" : "無效的圖片",
    "An error occurred. Please contact your admin." : "發生錯誤，請聯絡管理員",
    "No temporary profile picture available, try again" : "沒有臨時用的大頭貼，請再試一次",
    "No crop data provided" : "未設定剪裁",
    "No valid crop data provided" : "未提供有效的剪裁設定",
    "Crop is not square" : "剪裁設定不是正方形",
    "Couldn't reset password because the token is invalid" : "無法重設密碼因為 token 無效",
    "Couldn't reset password because the token is expired" : "無法重設密碼，因為 token 過期",
    "%s password reset" : "%s 密碼重設",
    "Couldn't send reset email. Please contact your administrator." : "無法寄送重設 email ，請聯絡系統管理員",
    "Couldn't send mail to following users: %s " : "無法寄送郵件給這些使用者：%s",
    "Preparing update" : "準備更新",
    "Repair warning: " : "修復警告：",
    "Repair error: " : "修復錯誤",
    "Turned on maintenance mode" : "已啓用維護模式",
    "Turned off maintenance mode" : "已停用維護模式",
    "Maintenance mode is kept active" : "維護模式維持在開啟狀態",
    "Updating database schema" : "更新資料庫格式",
    "Updated database" : "已更新資料庫",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "檢查是否有可更新的資料庫格式（若資料庫較大，可能需要一段時間）",
    "Checked database schema update" : "已檢查資料庫格式更新",
    "Checking updates of apps" : "檢查 app 更新",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "檢查 %s 是否有可更新的資料庫格式（若資料庫較大，可能需要一段時間）",
    "Checked database schema update for apps" : "已檢查應用程式的資料庫格式更新",
    "Updated \"%s\" to %s" : "已更新 %s 到 %s",
    "Set log level to debug" : "設定紀錄變成除錯層級",
    "Reset log level" : "重設記錄層級",
    "Starting code integrity check" : "開始檢查程式碼完整性",
    "Finished code integrity check" : "完成程式碼完整性檢查",
    "%s (3rdparty)" : "%s (第3方)",
    "%s (incompatible)" : "%s (不相容的)",
    "Following apps have been disabled: %s" : "以下應用程式已經被停用：%s",
    "Already up to date" : "已經是最新版",
    "Sunday" : "週日",
    "Monday" : "週一",
    "Tuesday" : "週二",
    "Wednesday" : "週三",
    "Thursday" : "週四",
    "Friday" : "週五",
    "Saturday" : "週六",
    "Sun." : "日",
    "Mon." : "一",
    "Tue." : "二",
    "Wed." : "三",
    "Thu." : "四",
    "Fri." : "五",
    "Sat." : "六",
    "Su" : "日",
    "Mo" : "一",
    "Tu" : "二",
    "We" : "三",
    "Th" : "四",
    "Fr" : "五",
    "Sa" : "六",
    "January" : "一月",
    "February" : "二月",
    "March" : "三月",
    "April" : "四月",
    "May" : "五月",
    "June" : "六月",
    "July" : "七月",
    "August" : "八月",
    "September" : "九月",
    "October" : "十月",
    "November" : "十一月",
    "December" : "十二月",
    "Jan." : "一月",
    "Feb." : "二月",
    "Mar." : "三月",
    "Apr." : "四月",
    "May." : "五月",
    "Jun." : "六月",
    "Jul." : "七月",
    "Aug." : "八月",
    "Sep." : "九月",
    "Oct." : "十月",
    "Nov." : "十一月",
    "Dec." : "十二月",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">執行程式碼完整性檢查時發生問題。更多資訊…</a>",
    "Settings" : "設定",
    "Saving..." : "儲存中...",
    "seconds ago" : "幾秒前",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "重設密碼的連結已經 email 至你的信箱，如果你在一段時間內沒收到，請檢查垃圾郵件資料夾，如果還是找不到，請聯絡系統管理員。",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "您的檔案是加密的，如果您沒有啟用救援金鑰，當您重設密碼之後將無法存取您的資料。<br/>如果不確定該怎麼做，請聯絡您的系統管理員。<br/>您確定要繼續嗎？",
    "I know what I'm doing" : "我知道我在幹嘛",
    "Password can not be changed. Please contact your administrator." : "無法變更密碼，請聯絡您的系統管理員",
    "No" : "否",
    "Yes" : "是",
    "Choose" : "選擇",
    "Error loading file picker template: {error}" : "載入檔案選擇器樣板出錯： {error}",
    "Ok" : "好",
    "Error loading message template: {error}" : "載入訊息樣板出錯： {error}",
    "read-only" : "唯讀",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} 個檔案衝突"],
    "One file conflict" : "一個檔案衝突",
    "New Files" : "新檔案",
    "Already existing files" : "已經存在的檔案",
    "Which files do you want to keep?" : "您要保留哪一個檔案？",
    "If you select both versions, the copied file will have a number added to its name." : "如果您同時選擇兩個版本，被複製的那個檔案名稱後面會加上編號",
    "Cancel" : "取消",
    "Continue" : "繼續",
    "(all selected)" : "（已全選）",
    "({count} selected)" : "（已選 {count} 項）",
    "Error loading file exists template" : "載入檔案存在樣板出錯",
    "Very weak password" : "密碼強度非常弱",
    "Weak password" : "密碼強度弱",
    "So-so password" : "密碼強度普通",
    "Good password" : "密碼強度佳",
    "Strong password" : "密碼強度極佳",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "您的網頁伺服器無法提供檔案同步功能，因為 WebDAV 界面有問題",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "伺服器沒有網際網路連線，有些功能，像是外部儲存、更新版通知將無法運作。從遠端存取資料或是寄送 email 通知可能也無法運作。建議您設定好網際網路連線以使用所有功能。",
    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "您的資料目錄和您的檔案可能從網路網路被存取，使.htaccess 檔案無法發揮效果，我們強烈建議您配置您的網頁伺服器讓資料目錄不再被訪問存取或者將您的資料目錄移出網頁伺服器根目錄。",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP 標頭配置與 \"{expected}\"不一樣，這是一個潛在安全性或者隱私上的風險，因此我們建議您調整此設定",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "您正在藉由 HTTP 訪問此網站，如我們的<a href=\"{docUrl}\">安全性提示</a>所述，我們強烈建議設定您的伺服器須要求使用 HTTPS",
    "Shared" : "已分享",
    "Shared with {recipients}" : "與 {recipients} 分享",
    "Error" : "錯誤",
    "Error while sharing" : "分享時發生錯誤",
    "Error while unsharing" : "取消分享時發生錯誤",
    "The public link will expire no later than {days} days after it is created" : "這個公開連結會在 {days} 天內失效",
    "Set expiration date" : "指定到期日",
    "Expiration" : "過期",
    "Expiration date" : "到期日",
    "Link" : "連結",
    "Edit" : "編輯",
    "Remove" : "移除",
    "Choose a password for the public link" : "為公開連結選一個密碼",
    "Filename" : "檔案名稱",
    "Password" : "密碼",
    "Name" : "名稱",
    "Allow editing" : "允許編輯",
    "Save" : "儲存",
    "Error while sending notification" : "發送通知錯誤",
    "Sending ..." : "正在傳送…",
    "Email sent" : "Email 已寄出",
    "Email link to person" : "將連結 email 給別人",
    "Shared with you and the group {group} by {owner}" : "由 {owner} 分享給您和 {group}",
    "Shared with you by {owner}" : "{owner} 已經和您分享",
    "group" : "群組",
    "remote" : "遠端",
    "notify by email" : "以 email 通知",
    "Unshare" : "取消分享",
    "can share" : "可分享",
    "can edit" : "可編輯",
    "create" : "建立",
    "change" : "更動",
    "delete" : "刪除",
    "access control" : "存取控制",
    "Could not unshare" : "無法取消分享",
    "Share details could not be loaded for this item." : "無法載入分享細節",
    "No users or groups found for {search}" : "沒有群組或使用者符合 {search}",
    "No users found for {search}" : "沒有使用者符合 {search}",
    "{sharee} (group)" : "{sharee} （群組）",
    "{sharee} (at {server})" : "{sharee} （在 {server}）",
    "{sharee} (remote)" : "{sharee} （遠端）",
    "Share" : "分享",
    "Resharing is not allowed" : "不允許重新分享",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "與其他在ownCloud上的人們分享，請使用此格式 username@example.com/owncloud",
    "Share with users…" : "分享給其他使用者…",
    "Share with users, groups or remote users…" : "分享給其他使用者、群組或遠端使用者…",
    "Share with users or groups…" : "分享給群組或使用者…",
    "Share with users or remote users…" : "分享給使用者或遠端使用者…",
    "Error removing share" : "移除分享時發生錯誤",
    "Warning" : "警告",
    "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
    "invisible" : "不可見",
    "({scope})" : "（{scope}）",
    "Delete" : "刪除",
    "Rename" : "重新命名",
    "Collaborative tags" : "標籤",
    "The object type is not specified." : "未指定物件類型",
    "Enter new" : "輸入新的",
    "Add" : "增加",
    "Edit tags" : "編輯標籤",
    "Error loading dialog template: {error}" : "載入對話樣板出錯：{error}",
    "No tags selected for deletion." : "沒有選擇要刪除的標籤",
    "unknown text" : "未知的文字",
    "Hello world!" : "哈囉 世界!",
    "sunny" : "晴朗的",
    "Hello {name}, the weather is {weather}" : "哈囉 {name}, 天氣是 {weather}",
    "Hello {name}" : "哈囉 {name}",
    "new" : "新",
    "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些狀況下，離開本頁面可能會導致更新中斷",
    "An error occurred." : "發生錯誤",
    "Please reload the page." : "請重新整理頁面",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗，檢視<a href=\"{url}\">論壇上的文章</a>來瞭解更多",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "升級失敗，請將此問題回報 <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud 社群</a>。",
    "The update was successful. There were warnings." : "更新成功，有警告訊息",
    "The update was successful. Redirecting you to ownCloud now." : "升級成功，正將您重新導向至 ownCloud 。",
    "Searching other places" : "搜尋其他位置",
    "No search results in other folders" : "在其他資料夾中沒有找到",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["在其他資料夾中有 {count} 比結果"],
    "Personal" : "個人",
    "Users" : "使用者",
    "Apps" : "應用程式",
    "Admin" : "管理",
    "Help" : "說明",
    "Access forbidden" : "存取被拒",
    "File not found" : "找不到檔案",
    "The specified document has not been found on the server." : "該文件不存在於伺服器上",
    "You can click here to return to %s." : "點這裡以回到 %s",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "嗨，\n\n%s 和你分享了 %s ，到這裡看它：%s\n",
    "The share will expire on %s." : "這個分享將會於 %s 過期",
    "Cheers!" : "太棒了！",
    "Internal Server Error" : "內部伺服器錯誤",
    "The server encountered an internal error and was unable to complete your request." : "伺服器遭遇內部錯誤，無法完成您的要求",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "如果這個錯誤重複出現，請聯絡系統管理員，並附上以下的錯誤細節",
    "More details can be found in the server log." : "伺服器記錄檔裡面有更多細節",
    "Technical details" : "技術細節",
    "Remote Address: %s" : "遠端位置：%s",
    "Request ID: %s" : "請求編號：%s",
    "Type: %s" : "類型：%s",
    "Code: %s" : "代碼：%s",
    "Message: %s" : "訊息：%s",
    "File: %s" : "檔案：%s",
    "Line: %s" : "行數：%s",
    "Trace" : "追蹤",
    "Create an <strong>admin account</strong>" : "建立一個<strong>管理者帳號</strong>",
    "Username" : "使用者名稱",
    "Storage & database" : "儲存空間和資料庫",
    "Data folder" : "資料儲存位置",
    "Configure the database" : "設定資料庫",
    "Only %s is available." : "剩下 %s 可使用",
    "Install and activate additional PHP modules to choose other database types." : "安裝並啟用相關 PHP 模組來使用其他種資料庫",
    "For more details check out the documentation." : "更多細節詳見說明文件",
    "Database user" : "資料庫使用者",
    "Database password" : "資料庫密碼",
    "Database name" : "資料庫名稱",
    "Database tablespace" : "資料庫 tablespace",
    "Database host" : "資料庫主機",
    "Performance warning" : "效能警告",
    "SQLite will be used as database." : "將使用 SQLite 為資料庫",
    "For larger installations we recommend to choose a different database backend." : "在大型安裝中建議使用其他種資料庫",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "若使用桌面版程式同步檔案，不建議使用 SQLite",
    "Finish setup" : "完成設定",
    "Finishing …" : "即將完成…",
    "Need help?" : "需要幫助？",
    "See the documentation" : "閱讀說明文件",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "嗨，<br><br>%s 與你分享了<strong>%s</strong>。<br><a href=\"%s\">檢視</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "這個應用程式需要啟用 Javascript 才能正常運作，請{linkstart}啟用Javascript{linkend}然後重新整理頁面。",
    "Log out" : "登出",
    "Search" : "搜尋",
    "Server side authentication failed!" : "伺服器端認證失敗！",
    "Please contact your administrator." : "請聯絡系統管理員",
    "Please try again or contact your administrator." : "請重試或聯絡系統管理員",
    "Log in" : "登入",
    "Wrong password. Reset it?" : "密碼錯誤，重設密碼？",
    "Wrong password." : "密碼錯誤",
    "Stay logged in" : "保持登入狀態",
    "Alternative Logins" : "其他登入方法",
    "Use the following link to reset your password: {link}" : "請至以下連結重設您的密碼： {link}",
    "New password" : "新密碼",
    "New Password" : "新密碼",
    "Reset password" : "重設密碼",
    "This ownCloud instance is currently in single user mode." : "這個 ownCloud 伺服器目前運作於單一使用者模式",
    "This means only administrators can use the instance." : "這表示只有系統管理員能夠使用",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員",
    "Thank you for your patience." : "感謝您的耐心",
    "You are accessing the server from an untrusted domain." : "你正在從一個未信任的網域存取伺服器",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "請聯絡您的系統管理員，如果您就是系統管理員，請設定 config/config.php 中的 \"trusted_domain\" 選項。範例設定提供於 config/config.sample.php。",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "依照設定而定，您身為系統管理員可能也可以使用底下的按鈕來信任這個網域",
    "Add \"%s\" as trusted domain" : "將 %s 加入到信任的網域",
    "App update required" : "需要更新應用程式",
    "%s will be updated to version %s" : "%s 將會更新至版本 %s",
    "These apps will be updated:" : "將會更新這些應用程式",
    "The theme %s has been disabled." : "主題 %s 已經被停用",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份資料庫、config 目錄及資料目錄",
    "Start update" : "開始升級",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "在大型安裝上，為了避免升級請求逾時，你也可以在安裝目錄執行下列指令：",
    "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 安裝目前處於維護模式，需要一段時間恢復。",
    "This page will refresh itself when the %s instance is available again." : "%s 安裝恢復可用之後，本頁會自動重新整理",
    "Expiration date is required" : "需要過期日期",
    "Remove link" : "移除連結",
    "Copy to clipboard" : "複製到剪貼簿",
    "Choose a password" : "選擇密碼",
    "Password required" : "需要密碼",
    "Public Links" : "公共連結",
    "Menu" : "選單",
    "Link name" : "連結名稱",
    "Imprint" : "法律聲明",
    "Could not reset password because the token is invalid" : "無法重設密碼，因為令牌無效",
    "Could not reset password because the token expired" : "無法重設密碼，因為令牌過期",
    "Could not reset password because the token does not match" : "無法重設密碼，因為令牌不符",
    "%s password changed successfully" : "%s 密碼修改成功",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Dismiss" : "忽略",
    "Delete {link}" : "刪除 {link}",
    "{fileName} link" : "{fileName} 連結",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "按下 ⌘-C 以複製",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 以複製",
    "Sending" : "傳送中",
    "User and Groups" : "使用者及群組",
    "Username or email" : "使用者名稱或電子郵件",
    "Create public link" : "建立公開連結",
    "Remove password" : "移除密碼",
    "Couldn't send mail to following recipient(s): %s " : "無法發送郵件給以下人員：%s",
    "Choose an expiration date" : "選擇到期日期",
    "Social share" : "社群分享",
    "Download / View" : "下載 / 檢視",
    "Download / View / Upload" : "下載 / 檢視 / 上傳",
    "Share to Twitter. Opens in a new window." : "分享到 Twitter。開啟新視窗。",
    "Share to Facebook. Opens in a new window." : "分享到 Facebook。開啟新視窗。",
    "Share to Diaspora. Opens in a new window." : "分享到 Diaspora。開啟新視窗。",
    "Share to Google+. Opens in a new window." : "分享到 Google+。開啟新視窗。",
    "Share via email. Opens your mail client." : "分享到電子郵件。開啟郵件客戶端。",
    "Add personal message" : "新增個人訊息",
    "Updating to {version}" : "更新至 {version}",
    "Cancel login" : "取消登入",
    "An error occurred while verifying the token" : "驗證令牌時發生錯誤",
    "Upload only" : "僅上傳",
    "Two-step verification" : "兩步驟驗證",
    "Update needed" : "需要更新"
},
"nplurals=1; plural=0;");
